%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%% LaTeX document class: eiscat.cls
%% Document class for writing documents for the EISCAT project
%%
%%
%% Created by: Gustav Johansson, Dec 21, 2005.
%%
%% Derived from the Johan Carlson's "eis_msc_thesis.cls"
%%
%% This document class is free to use, copy, distribute,
%% and modify, as long as reference to original author
%% is given.
%%
%% Current version: 1.0
%% Last modified by: Gustav Johansson, Dec 21, 2005.
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

% *******************************************************************
% Identification
% *******************************************************************
\NeedsTeXFormat{LaTeX2e}
\ProvidesClass{eiscat}
\def\thetemplateversion{1.0}

\PassOptionsToPackage{bookmarks=true,%
  bookmarksopen=true,%
  pdfborder={0 0 0},%
  pdfhighlight={/N},%
  linkbordercolor={.5 .5 .5},%
  raiselinks=true,%
  nesting=false}{hyperref}




% *******************************************************************
% Declare Options
% *******************************************************************
\DeclareOption*{\PassOptionsToClass{\CurrentOption}{report}}

% *******************************************************************
% Process Options
% *******************************************************************
\ProcessOptions*

% *******************************************************************
% Load Used Packages and Classes
% *******************************************************************
\LoadClass[a4paper]{report}
\RequirePackage{graphicx}
\RequirePackage{amsmath}
\RequirePackage{amsfonts}
\RequirePackage{amssymb}
\RequirePackage{ifthen}
\RequirePackage[english]{babel}
\RequirePackage{pdfpages}
\RequirePackage{eiscat}
\RequirePackage{palatino}\fontfamily{ppl}
\RequirePackage{hyperref}

%% *******************************************************************
%% Start defining and redefining stuff
%% *******************************************************************

%Define some new colors...
\definecolor{Border.An}{rgb}{.50,.00,.00}
\definecolor{Fill.An}{rgb}{.82,.70,.70}
\definecolor{Conn.An}{rgb}{.90,.00,.00}

\definecolor{Border.ASIC}{rgb}{.00,.00,.50}
\definecolor{Fill.ASIC}{rgb}{.70,.70,.82}
\definecolor{Conn.ASIC}{rgb}{.00,.00,.90}

\definecolor{Border.Array}{rgb}{.50,.33,.00}
\definecolor{Fill.Array}{rgb}{.90,.75,.45}
\definecolor{Conn.Array}{rgb}{.90,.60,.00}

\definecolor{Border.Base}{rgb}{.00,.50,.00}
\definecolor{Fill.Base}{rgb}{.70,.82,.70}
\definecolor{Conn.Base}{rgb}{.00,.90,.00}


% *******************************************************************

% This part defines the look of the lists!
\usepackage{paralist}
	\setdefaultitem{\textendash}{\textendash}{\textendash}{\textendash}

% This part defines the pagestyle!
\usepackage{fancyhdr,lastpage}
	\pagestyle{fancy}			
	\fancyhead[OC]{\fontfamily{phv}\hspace*{35mm}\includegraphics[height=12mm]{logo_eiscat}%
		\kern -0.5em\textsf{\color{EISBlue}\EIS}}
	\fancyhead[EC]{\hspace*{-10mm}\includegraphics[height=12mm]{logo_eiscat}%
		\kern-0.5em\textsf{\color{EISBlue}\EIS}}
	\fancyfoot[OC]{\hspace*{22mm}- \thepage{} -}
	\fancyfoot[EC]{\hspace*{-22mm}- \thepage{} -}
	\fancyhead[L,R]{}
\setlength{\topmargin}{0mm}
\setlength{\textwidth}{6.25in}
\setlength{\textheight}{8.75in}
\setlength{\evensidemargin}{-4.5mm}
\setlength{\oddsidemargin}{5.5mm}
\setlength{\headheight}{13.5mm}
\setlength{\headsep}{4mm}
% This part defines the pagestyle!


\DeclareRobustCommand\Exp{\text{\scriptsize{E}}}



%%-------------------------------------------------------
%%  Make title 
%%-------------------------------------------------------
\newcommand{\titletext}[1]{\fontfamily{phv}\title{\includegraphics[height=30mm]{logo_eiscat}\\%
				#1\\%
				\textsc{EISCAT Scientific Association}}}

% *******************************************************************
% Sections, subsections, etc.
% *******************************************************************

% This part defines the sectioning commands!
\usepackage[sf, bf]{titlesec} %!Check this for palatino font!!!
\titleformat{\chapter}[hang]{\sffamily\bfseries\huge}{\thechapter}{1em}{}
\titleformat{\section}[hang]{\sffamily\bfseries\Large}{\thesection}{1em}{}
\titleformat{\subsection}[hang]{\sffamily\bfseries}{\thesubsection}{1em}{}
\titleformat{\subsubsection}[hang]{\sffamily\bfseries}{\thesubsubsection}{1em}{}
\titleformat{\paragraph}[hang]{\sffamily\bfseries}{\theparagraph}{1em}{\textit}
\titleformat{\subparagraph}[hang]{\sffamily\bfseries}{\thesubparagraph}{1em}{\textit}
\titlespacing{\chapter}{0em}{3ex}{1ex}
\titlespacing{\section}{0em}{3ex}{1ex}
\titlespacing{\subsection}{0em}{3ex}{1ex}
\titlespacing{\subsubsection}{0em}{3ex}{1ex}
\titlespacing{\paragraph}{3.1em}{3ex}{1ex}
\titlespacing{\subparagraph}{5em}{3ex}{1ex}
\setcounter{secnumdepth}{5}%Shows numbering deeper! (down to subparagraph!)
